from setuptools import setup

setup(name='sgb_distribution',
      version='4.0',
      description='Gaussian and Binomial Distributions',
      packages=['sgb_distribution'],
      author = 'Shivam Wankhade',
      author_email = 'shivamwankhade12@gmail.com',
      zip_safe=False)
